pub enum Transport {
Tcp(String),
Uds(PathBuf),
Turmoil06(String),
Turmoil07(String),
}Expand description
Transport used for communication between nodes.
Variants
Tcp(String)
TCP transport (“tcp://host:port”).
Uds(PathBuf)
Available on Unix only.
Unix domain socket transport (“uds://path/to/socket”).
Used only on UNIX systems, ignored on other platforms.
Turmoil06(String)
Available on crate feature
turmoil06 only.Turmoil v0.6 transport (“turmoil06://host:port”).
A port can be omitted, in which case the default port is 57840 (0xE1F0).
Useful for testing purposes only.
Turmoil07(String)
Available on crate feature
turmoil07 only.Turmoil v0.7 transport (“turmoil07://host:port”).
A port can be omitted, in which case the default port is 57840 (0xE1F0).
Useful for testing purposes only.