pub struct DiscoveryConfig {
pub predefined: Vec<Transport>,
pub attempt_interval: Duration,
}Expand description
How to discover other nodes.
Fields
predefined: Vec<Transport>Predefined list of transports to connect to.
If changed, all existing connections related to removed transports are closed immediately. New connections are created for added transports.
attempt_interval: DurationHow often to attempt to connect to other nodes.
10s by default.