pub struct CompressionConfig {
pub lz4: Preference,
}Expand description
Compression settings.
Preference
By default, compression between nodes is supported but not enabled.
If a node is configured with Preferred for some compression algorithm,
all connections with this node will use this algorithm, until the other side
explicitly disables it.
See Preference for more details.
Example
[system.network]
compression.lz4 = "Preferred"Fields
lz4: PreferenceLZ4 compression algorithm.